#  tests for pygobject-3.42.0-py39hab2898f_2 (this is a generated file);
print('===== testing package: pygobject-3.42.0-py39hab2898f_2 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import gi
gi.require_version("GLib", "2.0")
assert("__init__" in gi.__file__)
from gi.repository import GLib
assert(31 == GLib.Date.get_days_in_month(GLib.DateMonth.JANUARY, 2000))

#  --- run_test.py (end) ---

print('===== pygobject-3.42.0-py39hab2898f_2 OK =====');
print("import: 'gi'")
import gi

print("import: 'gi.pygtkcompat'")
import gi.pygtkcompat

print("import: 'gi.repository.GLib'")
import gi.repository.GLib

